# 0.2.0

* `gadk check` has been added to check if the generated workflow files match
what would be generated by running `gadk`. This is useful for CI jobs to ensure
that the `actions.py` file is modified, not the workflow files.
* `gadk --version` has been added to print the version of GADK.
* BUG FIX: `Workflow.on` does not error when specifying only `pull_request` or `push`.
* README has been expanded with instructions.

# 0.1.2

* Generated files now start with a comment to prevent manual modification.

# 0.1.1

* Abstractions of workflows are now supported:
  ```python
  class BaseService(Workflow, ABC):
     @abstractmethod
     def concrete_data(self):
        pass

  class ServiceA(BaseService):
    pass
  ```
  In the example above, `ServiceA` will be detected as a workflow.
  `BaseService` will not be rendered as expected; only concrete workflows
  are rendered.
* The `workflow.on.branches` is now rendered before `workflow.on.paths`.

# 0.1.0

* Initial release.
* Basic features of workflows supported.
* `Artifact` abstraction included.
